/*
 * Copyright (c) 2002-2015 Oracle and/or its affiliates. All rights reserved.
 */

package javasoft.sqe.tests.javax.mail.Message;

import java.util.*;
import java.io.*;
import javax.mail.*;
import javax.mail.internet.*;
import com.sun.javatest.*;
import javasoft.sqe.tests.javax.mail.util.MailTest;

/**
 * This class tests the <strong>getMessageNumber()</strong> API.
 * It does this by invoking the test api and then checking
 * the type of the returned object.	<p>
 *
 *		Get the Message number for this Message.<p>
 * api2test: public int getMessageNumber()  <p>
 *
 * how2test: Call this API for any message and verify that it returns an integers number.
 *	     If this operation is successfull then this testcase passes, otherwise it fails.<p>
 *
 *	     A Message object's message number is the relative position <p>
 *	     of this Message in its Folder. A derived or newly composed
 *	     message has 0 as their message number.
 */

public class getMessageNumber_Test extends MailTest {

    public static void main( String argv[] )
    {
        getMessageNumber_Test test = new getMessageNumber_Test();
        Status s = test.run(argv, System.err, System.out);
	s.exit();
    }

    public Status run(String argv[], PrintWriter log, PrintWriter out)
    {
	super.run(argv, log, out);
	parseArgs(argv);	// parse command-line options

        out.println("\nTesting class Message: getMessageNumber()\n");

        try {
          // Connect to host server
             Store store = connect2host(protocol, host, user, password);

          // Get a Folder object
	     Folder root = getRootFolder(store);
             Folder folder = root.getFolder(mailbox);

             if ( folder == null ) {
                  return Status.failed("Invalid folder object!");
             }
             folder.open(Folder.READ_ONLY);

	     if( msgcount == -1 ) {
                 msgcount = folder.getMessageCount();
                 if( msgcount < 1 )
                     return Status.failed("Mail folder is empty!");
             }
	     int msgid;

             for( int i = 1; i <= msgcount; i++ )
             {
            // Get the message
               MimeMessage msg = (MimeMessage)folder.getMessage(i);

	       if( msg == null ) {
		   log.println("WARNING: FAILED TO GET MESSAGE NUMBER: "+ i);
		   continue;
	       }
	    // BEGIN UNIT TEST:
	       // Get message number
	       out.println("UNIT TEST "+ i +":  getMessageNumber()");

	       msgid = msg.getMessageNumber();	// API TEST

	       if( msgid == i )
                   out.println("UNIT TEST "+ i +":  passed\n");
	       else {
		     out.println("UNIT TEST "+ i +":  FAILED\n");
		     errors++;
	       }
	    // END UNIT TEST:
	     }
	     folder.close(false);
	     store.close();
	     checkStatus();

        } catch ( Exception e ) {
	     handlException(e);
        }
	return status;
     }
}
